@@ -30,8 +30,12 @@
 #include <KLocalizedString>
 #include <QCoreApplication>
 
+#ifdef Q_OS_WIN
+#include <Winsock2.h>
+#else
 #include <netdb.h>
 #include <netinet/in.h>
+#endif
 #include <sys/stat.h>
 
 using namespace KIO;
@@ -189,7 +193,7 @@ void LDAPProtocol::controlsFromMetaData(LdapControls &serverctrls,
         Ldif::splitControl(val, oid, critical, value);
         qCDebug(KLDAP_LOG) << "server ctrl #" << i << " value: " << val <<
                            " oid: " << oid << " critical: " << critical << " value: " <<
-                           QString::fromUtf8(value, value.size()) << endl;
+                           QString::fromUtf8(value.constData(), value.size()) << endl;
         LdapControl ctrl(oid, val, critical);
         serverctrls.append(ctrl);
         i++;
@@ -200,7 +204,7 @@ void LDAPProtocol::controlsFromMetaData(LdapControls &serverctrls,
         Ldif::splitControl(val, oid, critical, value);
         qCDebug(KLDAP_LOG) << "client ctrl #" << i << " value: " << val <<
                            " oid: " << oid << " critical: " << critical << " value: " <<
-                           QString::fromUtf8(value, value.size()) << endl;
+                           QString::fromUtf8(value.constData(), value.size()) << endl;
         LdapControl ctrl(oid, val, critical);
         clientctrls.append(ctrl);
         i++;
@@ -215,7 +219,7 @@ void LDAPProtocol::LDAPEntry2UDSEntry(const LdapDN &dn, UDSEntry &entry,
     entry.clear();
     QString name = dn.toString();
     if ((pos = name.indexOf(QLatin1Char(','))) > 0) {
-        name = name.left(pos);
+        name.truncate(pos);
     }
     if ((pos = name.indexOf(QLatin1Char('='))) > 0) {
         name.remove(0, pos + 1);
@@ -288,7 +292,7 @@ void LDAPProtocol::setHost(const QString &host, quint16 port,
         mServer.setPort(port);
     } else {
         struct servent *pse;
-        if ((pse = getservbyname(mProtocol, "tcp")) == nullptr) {
+        if ((pse = getservbyname(mProtocol.constData(), "tcp")) == nullptr) {
             if (mProtocol == "ldaps") {
                 mServer.setPort(636);
             } else {
